@@ -89,7 +89,8 @@ ParleyDocument::~ParleyDocument()
 {
     close();
     delete m_backupTimer;
-    delete m_doc;
+    m_doc->deleteLater();
+    emit documentChanged(0);
 }
 
 
@@ -98,8 +99,6 @@ KEduVocDocument *ParleyDocument::document()
     // If there is no present vocabulary document, create an empty one.
     if (!m_doc) {
         m_doc = new KEduVocDocument();
-        m_doc->setTitle( i18n("Untitled") );
-        m_doc->setGenerator( QString::fromLatin1("Parley ") + PARLEY_VERSION_STRING );
     }
 
     return m_doc;
@@ -107,9 +106,7 @@ KEduVocDocument *ParleyDocument::document()
 
 void ParleyDocument::setTitle(const QString& title)
 {
-    m_doc->setModified(true);
     m_doc->setTitle(title);
-    m_parleyApp->slotUpdateWindowCaption(); // FIXME: This is what signals are for.  The document should *not* directly call it's owner. What if there are >1 window, for instance?
 }
 
 void ParleyDocument::slotFileNew()
@@ -146,12 +143,13 @@ void ParleyDocument::newDocument(bool wizard)
     }
 
     close();
+    if (m_doc) {
+        m_doc->deleteLater();
+    }
     m_doc = newDoc;
-
     emit documentChanged(m_doc);
     enableAutoBackup(Prefs::autoBackup());
 
-
     if (fetchGrammarOnline) {
         DocumentHelper::fetchGrammar(m_doc, 0);
         DocumentHelper::fetchGrammar(m_doc, 1);
@@ -197,7 +195,12 @@ bool ParleyDocument::open(const KUrl & url)
     }
 
     close();
+
+    if (m_doc) {
+        m_doc->deleteLater();
+    }
     m_doc = new KEduVocDocument(this);
+    emit documentChanged(m_doc);
     m_doc->setCsvDelimiter(Prefs::separator());
 
     bool isSuccess = false, isError = false;
@@ -230,11 +233,8 @@ bool ParleyDocument::open(const KUrl & url)
     }
 
     if ( isSuccess ) {
-        kDebug() << "Open success.";
-        //m_parleyApp->editor()->updateDocument();
         m_parleyApp->addRecentFile(url, m_doc->title());
 
-        emit documentChanged(m_doc);
         enableAutoBackup(Prefs::autoBackup());
 
     } else {
@@ -243,7 +243,8 @@ bool ParleyDocument::open(const KUrl & url)
                 m_parleyApp, i18n("Opening collection \"%1\" resulted in an error: %2", m_doc->url().url(),
                                   m_doc->errorDescription(ret)), i18nc("@title:window", "Open Collection"));
         }
-        delete m_doc;
+        m_doc->deleteLater();
+        emit documentChanged(0);
         m_doc = 0;
     }
 
@@ -254,11 +255,11 @@ void ParleyDocument::close()
 {
     kDebug() << "Close Document";
     enableAutoBackup(false);
-    emit documentChanged(0);
-    disconnect(m_doc);
-    delete m_doc;
-    m_doc = 0;
-    m_parleyApp->slotUpdateWindowCaption();
+    if (m_doc) {
+        emit documentChanged(0);
+        m_doc->deleteLater();
+        m_doc = 0;
+    }
 }
 
 bool ParleyDocument::queryClose()
@@ -290,7 +291,6 @@ bool ParleyDocument::queryClose()
 
     if (canSave) {
         save();       // save and exit
-        document()->setModified(false);
     }
 
     close();
@@ -328,7 +328,6 @@ void ParleyDocument::save()
 
     emit statesNeedSaving();
 
-    QString oldgenerator = m_doc->generator();
     QString newgenerator = QString::fromLatin1("Parley ") + PARLEY_VERSION_STRING ;
     m_doc->setGenerator(newgenerator);
 
@@ -336,7 +335,6 @@ void ParleyDocument::save()
 
     KEduVocDocument::ErrorCode ret = m_doc->saveAs(
         m_doc->url() , KEduVocDocument::Automatic, KEduVocDocument::FileIgnoreLock);
-    m_doc->setGenerator(oldgenerator);
 
     switch ( ret ) {
     case KEduVocDocument::NoError :
@@ -350,7 +348,6 @@ void ParleyDocument::save()
         if ( exit == KMessageBox::Yes ) {
             m_doc->setGenerator(newgenerator );
             ret = m_doc->saveAs(m_doc->url() , KEduVocDocument::Automatic, KEduVocDocument::FileIgnoreLock);
-            m_doc->setGenerator(oldgenerator );
 
             if ( ret == KEduVocDocument::NoError ) {
                 isSuccess = true;
@@ -430,11 +427,9 @@ void ParleyDocument::saveAs(KUrl url)
             m_parleyApp, i18n("File \"%1\" is locked by another process.  You can save to the file if you take over the lock, but you will lose any changes from the other process.\n\nDo you want to take over the lock?\n"
                 , m_doc->url().url()), "");
         if ( exit == KMessageBox::Yes ) { //attempt lock steal
-            QString oldgenerator = m_doc->generator();
             m_doc->setGenerator(QString::fromLatin1("Parley ") + PARLEY_VERSION_STRING );
             ret = m_doc->saveAs(
                 m_doc->url() , KEduVocDocument::Automatic, KEduVocDocument::FileIgnoreLock);
-            m_doc->setGenerator(oldgenerator );
 
             if ( ret == KEduVocDocument::NoError ) {
                 isSuccess = true;
@@ -580,6 +575,7 @@ void ParleyDocument::documentProperties()
     connect(titleAuthorDialog, SIGNAL(accepted()), titleAuthorWidget, SLOT(accept()));
     titleAuthorDialog->exec();
     delete titleAuthorDialog;
+    emit documentChanged(m_doc);
 }
 
 void ParleyDocument::languageProperties()
